@@ -1,7 +1,7 @@
 use crate::map::*;
 use crate::convert::TryTo;
 
-use image::{ImageError, io::Reader as ImageReader, ImageFormat};
+use image::ImageError;
 use serde::{Serialize, Deserialize};
 use thiserror::Error;
 
@@ -477,19 +477,8 @@ impl Image {
     fn from_file(path: &Path) -> Result<Self, MapDirError> {
         match path.extension().unwrap().to_str().unwrap() {
             "json" => Ok(ExternalImage::deserialize_json(path)?.into()),
-            "png" => {
-                let mut reader = ImageReader::open(path)
-                    .err_with_path(path)?;
-                reader.set_format(ImageFormat::Png);
-                let image = reader.decode()
-                    .err_with_path(path)?
-                    .into_rgba8();
-
-                Ok(EmbeddedImage {
-                    name: String::new(),
-                    image: image.into(),
-                }.into())
-            }
+            "png" => Ok(EmbeddedImage::from_file(path)
+                .err_with_path(path)?.into()),
             _ => unreachable!(),
         }
     }
