@@ -6,13 +6,13 @@ use crate::constants::{
 use crate::map_checks::PhysicsLayerChecking;
 use crate::convert::{To, TryTo};
 
-use image::{RgbaImage, Pixel};
+use image::{RgbaImage, Pixel, ImageError, io::Reader as ImageReader, ImageFormat};
 use itertools::Itertools;
 use ndarray::{s, Array2};
 
 use std::io;
 use std::fs;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 use std::convert::TryFrom;
 use std::cmp::min;
 
@@ -68,6 +68,41 @@ impl TwMap {
     }
 }
 
+impl EmbeddedImage {
+    /// Creates a embedded image using a provided image file.
+    /// This function supports many more formats than just png.
+    /// Errors with an io::ErrorKind::InvalidInput if the filename includes invalid utf-8
+    pub fn from_file<P: AsRef<Path>>(path: P) -> Result<EmbeddedImage, ImageError> {
+        let path = path.as_ref();
+        let mut reader = ImageReader::open(path)?;
+        reader.set_format(ImageFormat::Png);
+        let image = reader.decode()?
+            .into_rgba8()
+            .into();
+        let name = match path.file_stem().unwrap().to_str() {
+            Some(str) => str.to_owned(),
+            None => return Err(io::Error::new(io::ErrorKind::InvalidInput, "The file name includes invalid utf-8").into()),
+        };
+        Ok(EmbeddedImage {
+            name,
+            image,
+        })
+    }
+}
+
+impl ExternalImage {
+    /// Tries to embed the external images by loading it from the file `mapres/<image_name>`
+    pub fn embed(&self) -> Result<EmbeddedImage, ImageError> {
+        let mut file_name = self.name.clone();
+        file_name.push_str(".png");
+
+        let mut path: PathBuf = "mapres".into();
+        path.push(file_name);
+
+        EmbeddedImage::from_file(path)
+    }
+}
+
 // takes care of multiple physics layers of the same type
 impl TwMap {
     /// Removes duplicate physics layers of each type.
