@@ -585,7 +585,7 @@ impl TileCompression for Tile {
         for &tile in &tiles[1..] {
             let current_tile = compressed_tiles.last_mut().unwrap();
 
-            if current_tile.skip == u8::max_value() { // maximum for tile skipping (255)
+            if current_tile.skip == u8::MAX { // maximum for tile skipping (255)
                 compressed_tiles.push(tile);
             } else {
                 if current_tile.id == tile.id && current_tile.flags == tile.flags {
@@ -607,7 +607,7 @@ impl TileCompression for GameTile {
         for &tile in &tiles[1..] {
             let current_tile = compressed_tiles.last_mut().unwrap();
 
-            if current_tile.skip == u8::max_value() { // maximum for tile skipping (255)
+            if current_tile.skip == u8::MAX { // maximum for tile skipping (255)
                 compressed_tiles.push(tile);
             } else {
                 if current_tile.id == tile.id && current_tile.flags == tile.flags {
@@ -658,13 +658,10 @@ trait PhysicsLayerSaving: TileMapLayer
             item_data.extend(&[-1; 5]);
             if Self::kind() != LayerKind::Game {
                 item_data[Self::kind().data_index()] = data_len + 1;
-                data_items.push(Cow::from(iter::repeat(0).take(width * height * mem::size_of:: < Tile>()).collect:: < Vec<_ > > ()));
+                data_items.push(Cow::from(iter::repeat(0).take(width * height * mem::size_of::< Tile>()).collect::<Vec<_>>()));
             }
         }
-        let mut tiles = self.tiles().unwrap_ref().clone()
-            .iter()
-            .map(|&tile| tile)
-            .collect::<Vec<Self::TileType>>();
+        let mut tiles = self.tiles().unwrap_ref().to_owned().into_raw_vec();
 
         if version == Version::Teeworlds07 && Self::kind() == LayerKind::Game {
             tiles = Self::TileType::compress_tiles(tiles);
@@ -737,9 +734,7 @@ impl TilesLayer {
         item_data[13] = from_u16_option_index(self.image); // image index
         item_data[14] = data_len;
         item_data[15..18].copy_from_slice(&string_to_i32s(&self.name, 3));
-        let mut tiles = tiles.iter()
-            .map(|&tile| tile)
-            .collect::<Vec<Tile>>();
+        let mut tiles = tiles.to_owned().into_raw_vec();
         if version == Version::Teeworlds07 {
             tiles = Tile::compress_tiles(tiles);
         }
